# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Archive-Zip
Version:	1.68
Release:	11.%{__distinit}%{__distvers}
Summary:	Perl library for accessing Zip archives
# lib/Archive/Zip/Member.pm:	(GPL-1.0-or-later OR Artistic-1.0-Perl) AND Info-ZIP
#				(The _mapPermissionsToUnix() comments are copied from Info-ZIP licensed unzip)
# other files:			GPL-1.0-or-later OR Artistic-1.0-Perl
License:	(GPL-1.0-or-later OR Artistic-1.0-Perl) AND Info-ZIP
URL:		https://metacpan.org/release/Archive-Zip
Source0:	https://cpan.metacpan.org/modules/by-module/Archive/Archive-Zip-%{version}.tar.gz
Patch0:		Archive-Zip-1.33-provides.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Compress::Raw::Zlib) >= 2.017
BuildRequires:	perl(constant)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Encode)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(FileHandle)
BuildRequires:	perl(integer)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(IO::Seekable)
BuildRequires:	perl(strict)
BuildRequires:	perl(Time::Local)
BuildRequires:	perl(utf8)
BuildRequires:	perl(vars)
# Script Runtime
BuildRequires:	perl(lib)
# Test Suite
BuildRequires:	perl(File::Spec::Unix)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(warnings)
# Optional Tests
BuildRequires:	unzip
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Exporter)
Requires:	perl(utf8)

%description
The Archive::Zip module allows a Perl program to create, manipulate,
read, and write Zip archive files.

Zip archives can be created, or you can read from existing zip files.
Once created, they can be written to files, streams, or strings.
Members can be added, removed, extracted, replaced, rearranged, and
enumerated.  They can also be renamed or have their dates, comments,
or other attributes queried or modified.  Their data can be compressed
or uncompressed as needed. Members can be created from members in
existing Zip files, or from existing directories, files, or strings.

%prep
%setup -q -n Archive-Zip-%{version}

# Don't provide perl(NedsFileHandle)
%patch -P 0

# Fix line endings
perl -pi -e 's|\r$||' lib/Archive/Zip/FAQ.pod

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes examples/
%{_bindir}/crc32
%dir %{perl_vendorlib}/Archive/
%dir %{perl_vendorlib}/Archive/Zip/
%{perl_vendorlib}/Archive/Zip.pm
%{perl_vendorlib}/Archive/Zip/Archive.pm
%{perl_vendorlib}/Archive/Zip/BufferedFileHandle.pm
%{perl_vendorlib}/Archive/Zip/DirectoryMember.pm
%{perl_vendorlib}/Archive/Zip/FileMember.pm
%{perl_vendorlib}/Archive/Zip/Member.pm
%{perl_vendorlib}/Archive/Zip/MemberRead.pm
%{perl_vendorlib}/Archive/Zip/MockFileHandle.pm
%{perl_vendorlib}/Archive/Zip/NewFileMember.pm
%{perl_vendorlib}/Archive/Zip/StringMember.pm
%{perl_vendorlib}/Archive/Zip/Tree.pm
%{perl_vendorlib}/Archive/Zip/ZipFileMember.pm
%doc %{perl_vendorlib}/Archive/Zip/FAQ.pod
%{_mandir}/man3/Archive::Zip.3*
%{_mandir}/man3/Archive::Zip::FAQ.3*
%{_mandir}/man3/Archive::Zip::MemberRead.3*
%{_mandir}/man3/Archive::Zip::Tree.3*

%changelog
* Fri Jul 14 2023 Paul Howarth <paul@city-fan.org> - 1.68-11
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Fri Mar 13 2020 Paul Howarth <paul@city-fan.org> - 1.68-1
- Update to 1.68
  - Switched to GitHub as issue tracker
  - Replaced references to Test::MockModule in t/23_closed_handle.t with code
    from GH#32 (CPAN RT#110087)
  - Unixified line endings in t/23_closed_handle.t
  - Added documentation for Archive::Zip::Member::isSymbolicLink
    (CPAN RT#130524)
  - Implemented other, unrelated doc fixes
  - Fixed examples/zipcheck.pl to skip symbolic links (CPAN RT#130525)
  - Described version 1.59 (CPAN RT#117371)
  - Completely re-did test suite:
    - Created new test APIs in t/common.pm and documented them in t/README.md
    - Changed tests to be less dependent on OS-specific quirks of "unzip -t"
    - Changed tests to write more diagnostic information if executed in
      automated test environments
    - Normalized access to test data and to temporary results; removed
      references to obsolete temporary results (for example, those to directory
      "extracted")
    - Normalized test headers and brushed up tests in general

* Mon Oct  7 2019 Paul Howarth <paul@city-fan.org> - 1.67-1
- Update to 1.67
  - Fixed compatibility issues with zip64 format (defined-or, pack)
  - Fixed hard-coded version fields introduced in version 1.66
  - Fixed merge glitch with tests 26 and 27
  - Fixed merge glitch with bzip passthrough
  - Updated bzip test file to avoid zip bomb detection
- Add workaround for unzip without bzip2 support
  https://github.com/redhotpenguin/perl-Archive-Zip/pull/63

* Tue Sep 17 2019 Paul Howarth <paul@city-fan.org> - 1.66-1
- Update to 1.66 (see Changes for details)

* Mon Sep  9 2019 Paul Howarth <paul@city-fan.org> - 1.65-1
- Update to 1.65
  - Fix for members using bzip compression
  - NetBSD doesn't mind empty zips
  - Solaris test failure, add diag to failing test to collect data
  - Test for presence of Test::MockModule
  - Fix skip line for Windows
  - Skip tests that assume /tmp on Windows

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 1.64-3
- Perl 5.30 rebuild

* Thu Sep 13 2018 Paul Howarth <paul@city-fan.org> - 1.64-1
- Update to 1.64
  - Fix for year 2030

* Wed Aug 22 2018 Paul Howarth <paul@city-fan.org> - 1.63-1
- Update to 1.63
  - Restore missing META.yml deps
  - Symlink traversal test fix
  - Added missing prereq Encode as suggested by CPANTS

* Mon Aug 20 2018 Paul Howarth <paul@city-fan.org> - 1.62-1
- Update to 1.62
  - Add link-samename.zip to MANIFEST

* Sun Aug 19 2018 Paul Howarth <paul@city-fan.org> - 1.61-1
- Update to 1.61
  - File::Find will not untaint
  - Prevent from traversing symlinks and parent directories when extracting
- Fix wrong argument 'untaint_pat' passed to File::Find
- Add test data missing from upstream release
- Switch upstream from search.cpan.org to metacpan.org

* Thu Dec 21 2017 Paul Howarth <paul@city-fan.org> - 1.60-1
- Update to 1.60
  - Wrong shell bang in examples/selfex.pl (CPAN RT#123913)
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Fri Aug 12 2016 Paul Howarth <paul@city-fan.org> - 1.59-1
- Update to 1.59
  - Update Makefile.PL metadata to CPAN Meta specification 2.0

* Wed Aug  3 2016 Paul Howarth <paul@city-fan.org> - 1.58-1
- Update to 1.58
  - Avoid relying on . being in @INC
  - Update MANIFEST.SKIP
- BR: perl-generators where available
- Simplify find command using -delete
- Update patch to support building with Test::More < 0.88

* Sat Apr  2 2016 Paul Howarth <paul@city-fan.org> - 1.57-1
- Update to 1.57
  - Work around bug in some versions of unzip (CPAN RT#106548, CPAN RT#106089,
    CPAN RT#105330, CPAN RT#111541)

* Fri Dec 18 2015 Paul Howarth <paul@city-fan.org> - 1.56-1
- Update to 1.56
  - Fix $Archive::Zip::UNICODE issues
  - On MSWin32 in methods addFile, addDirectory, addTree: the externalFileName
    was used in place of newName
  - Make sure that file names are utf8 in memberNames
  - Use Encode on all platform

* Mon Dec  7 2015 Paul Howarth <paul@city-fan.org> - 1.55-1
- Update to 1.55
  - Ensure filehandles created by Archive::Zip::tempFile are closed
  - Fix empty archive issue with OS X gnu tar (CPAN RT#110064)
- Drop workaround for non-standard tarballs, no longer needed

* Thu Sep 24 2015 Paul Howarth <paul@city-fan.org> - 1.53-1
- Update to 1.53
  - Rebuild with newer tools (CPAN RT#105902)

* Tue Sep 22 2015 Paul Howarth <paul@city-fan.org> - 1.51-1
- Update to 1.51
  - Compare vs filename checksum in crc32 script

* Wed Sep  2 2015 Paul Howarth <paul@city-fan.org> - 1.50-1
- Update to 1.50
  - Fix t/08_readmember_record_sep.t for Win32

* Sat Aug  1 2015 Paul Howarth <paul@city-fan.org> - 1.49-1
- Update to 1.49
  - Failed on unseekable file handle after desiredCompressionLevel() (CPAN RT#54827)
  - Upgrade build tools to avoid tar warnings (CPAN RT#105547)
- Drop upstreamed patch for CPAN RT#54827

* Fri Jun 19 2015 Paul Howarth <paul@city-fan.org> - 1.48-1
- Update to 1.48
  - Wrap skip in a SKIP: block
- Work around bug in GNU tar 1.15.1 that breaks extracting tarballs made with
  unknown extended attributes on old distributions

* Thu Jun 18 2015 Paul Howarth <paul@city-fan.org> - 1.47-1
- Update to 1.47
  - Zip file with a deflated directory could not be written out again
  - Add missing test data to MANIFEST

* Sat Jun 13 2015 Paul Howarth <paul@city-fan.org> - 1.46-2
- Perl 5.22 rebuild

* Wed Mar 25 2015 Paul Howarth <paul@city-fan.org> - 1.46-1
- Update to 1.46
  - "CRC or size mismatch" when extracting member second time
    (https://github.com/redhotpenguin/perl-Archive-Zip/issues/11)

* Tue Jan 27 2015 Paul Howarth <paul@city-fan.org> - 1.45-1
- Update to 1.45
  - Win32 with ZIP executable could not create temp file
  - FreeBSD unzip sets $? to 0 for empty zip file

* Thu Jan 15 2015 Paul Howarth <paul@city-fan.org> - 1.43-1
- Update to 1.43
  - Restore fix for CPAN RT#101374 - failing tests were not regressions

* Mon Jan 12 2015 Paul Howarth <paul@city-fan.org> - 1.42-1
- Update to 1.42
  - Revert fix for CPAN RT#101374, caused tester regression (CPAN RT#101240)

* Sun Jan 11 2015 Paul Howarth <paul@city-fan.org> - 1.41-1
- Update to 1.41
  - Fix test suite to work in absence of unzip (CPAN RT#101374)

* Tue Jan  6 2015 Paul Howarth <paul@city-fan.org> - 1.40-1
- Update to 1.40
  - Fix CRC error when re-writing Zip created by LibreOffice (CPAN RT#92205)
  - Avoid creation of non-standard streamed zip file (CPAN RT#101092)

* Wed Oct 22 2014 Paul Howarth <paul@city-fan.org> - 1.39-1
- Update to 1.39
  - Store test data in temp dirs to fix parallelism and shuffling
- Add patch to fix failure writing to an unseekable file handle after calling
  desiredCompressionLevel() (CPAN RT#54827)
- Classify buildreqs by usage
- Update patch to support building with Test::More < 0.88

* Thu Sep  4 2014 Paul Howarth <paul@city-fan.org> - 1.38-1
- Update to 1.38
  - Setting unicode flag for each member when using $Archive::Zip::UNICODE
    (CPAN RT#83367)
- Drop %%defattr, redundant since rpm 4.4

* Tue Jan 14 2014 Paul Howarth <paul@city-fan.org> - 1.37-1
- Update to 1.37
  - Need newer Test::More to support done_testing()

* Tue Dec 31 2013 Paul Howarth <paul@city-fan.org> - 1.36-1
- Update to 1.36
  - Fall back on copy if move gives permission denied

* Tue Dec  3 2013 Paul Howarth <paul@city-fan.org> - 1.34-1
- Update to 1.34
  - Restore svn history from svn.ali.as
  - Test 17 in t/03_ex.t was failing (CPAN RT#90854)
  - Allow reading ZIP from seekable streams, like PerlIO::Scalar
    (CPAN RT#75197)
  - Couldn't create member called "0" with addString (CPAN RT#76780)
- Upstream dropped LICENSE and README files, and the extra tests
- Drop no-longer-needed UTF8 patch
- Drop buildreqs needed for extra tests
- Fix the line endings for FAQ.pod

* Mon Nov 11 2013 Paul Howarth <paul@city-fan.org> - 1.33-1
- Update to 1.33
  - Experimental Unicode in file/dir names
  - Add decryption support
  - Updated Perl dependency to 5.006 to reflect implicit dependencies in the
    code exposed by Perl::MinimumVersion xt test
  - Set compressed size and uncompressed size of an entry to 0 if either of
    them is 0 (CPAN RT#68446)
  - Added $VERSION to crc32
  - Unlink temp files generated by tempFile (CPAN RT#89777)
  - Various minor bug fixes
  - Typo fixes (CPAN RT#59102, CPAN RT#86600)
- This release by PHRED -> update source URL
- Drop upstreamed minversion patch
- Explicitly run the extra tests
- Use a patch to hide the sample NedsFileHandle package from rpm, which
  removes the need for provides filters
- Add patch to support building with Test::More < 0.88

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 1.30-10
- Perl 5.16 post-bootstrap rebuild

* Sun Jul  1 2012 Paul Howarth <paul@city-fan.org> - 1.30-9
- BR: perl(Carp), perl(constant), perl(Cwd), perl(Data::Dumper),
  perl(Exporter), perl(File::Path), perl(File::Spec),
  perl(File::Spec::Unix), perl(File::Temp), perl(IO::File),
  perl(IO::Seekable) and perl(Time::Local)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Wed Feb  8 2012 Paul Howarth <paul@city-fan.org> - 1.30-6
- Don't BR: perl(Test::MinimumVersion) if we're bootstrapping
- Tweak fix for CPAN RT#52696 to require perl 5.005 since Archive::Zip uses
  the $! variable

* Tue Jun 21 2011 Paul Howarth <paul@city-fan.org> - 1.30-5
- Rebuild for perl 5.14.1 in Rawhide
- Fix provides filter to work with rpm 4.9 onwards
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 1.30-4
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 1.30-3
- Fix dist tag for RHEL-6 Beta

* Fri Feb 12 2010 Paul Howarth <paul@city-fan.org> - 1.30-2
- Add upstream fix for 99_pmv.t test failure (CPAN RT#52696)
- Filter bogus provide of perl(NedsFileHandle)
- Dist tag for Rawhide no longer needs special-casing

* Tue Jun 30 2009 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.30 (fix CPAN RT#47454 - Cwd::getcwd issue)
- Cwd::getcwd patch no longer needed

* Tue Jun 30 2009 Paul Howarth <paul@city-fan.org> - 1.29-1
- Update to 1.29 (fix CPAN RT#47223)
- Patch Zip.pm to call Cwd::getcwd in a more portable way

* Wed Jun 17 2009 Paul Howarth <paul@city-fan.org> - 1.28-1
- Update to 1.28 (many improvements and bugfixes - see Changes file)
- BR: Compress::Raw::Zlib rather than Compress::Zlib
- Mark FAQ.pod as %%doc

* Thu May  7 2009 Paul Howarth <paul@city-fan.org> - 1.26-1
- Import from Fedora
- Update to 1.26
- Drop File::Which buildreq, no longer needed
- Enable author tests in %%check
- Add buildreqs perl(Test::CPAN::Meta), perl(Test::MinimumVersion),
  perl(Test::Pod)

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.23-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri May 16 2008 Steven Pritchard <steve@kspei.com> 1.23-1
- Update to 1.23.

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.20-5
- Rebuild for perl 5.10 (again)

* Fri Jan 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.20-4
- rebuild for new perl

* Fri Aug 24 2007 Robin Norwood <rnorwood@redhat.com> - 1.20-3
- Fix license tag

* Wed Jun 27 2007 Robin Norwood <rnorwood@redhat.com> - 1.20-2
- Resolves: rhbz#226240
- Incorporate changes from Steven Pritchard's package review
- Fix find option order.
- Use fixperms macro instead of our own chmod incantation.
- Remove check macro cruft.
- Update build dependencies.
- Package LICENSE.
- BR unzip, zip for better test coverage.

* Tue Jun 05 2007 Robin Norwood <rnorwood@redhat.com> - 1.20-1
- Update to latest CPAN version: 1.20
- Fix broken changelog

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.16-1.2.1
- rebuild

* Fri Feb 03 2006 Jason Vas Dias<jvdias@redhat.com> - 1.16-1.2
- rebuilt for new perl-5.8.8

* Fri Dec 16 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt for new gcc

* Mon Jul 11 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.16-1
- Update to 1.16.

* Thu Apr 14 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.14-1
- Update to 1.14.

* Wed Apr  6 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
- rebuilt

* Sun Aug 15 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.12-0.fdr.1
- Update to 1.12.

* Tue Jul  6 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.11-0.fdr.1
- Update to 1.11.
- Bring up to date with current fedora.us Perl spec template.

* Sun Apr 18 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.10-0.fdr.1
- Update to 1.10.
- Reduce directory ownership bloat.
- Require perl(:MODULE_COMPAT_*).

* Fri Nov 28 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.09-0.fdr.1
- Update to 1.09.

* Wed Oct 22 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.08-0.fdr.1
- Update to 1.08.

* Tue Oct 21 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.07-0.fdr.1
- Update to 1.07.

* Sun Sep 14 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.06-0.fdr.1
- Update to 1.06.
- Specfile cleanups.

* Sun Jun  8 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.05-0.fdr.1
- First build.
